@@ -25,6 +25,7 @@
 import serial
 import string
 import time
+import os
 from math import ceil
 import wx #due to debugEvent messaging
 
@@ -96,13 +97,13 @@ class OBDPort:
              
          wx.PostEvent(self._notify_window, DebugEvent([1,"Interface successfully " + self.port.portstr + " opened"]))
          wx.PostEvent(self._notify_window, DebugEvent([1,"Connecting to ECU..."]))
-         print self.State
+         #print self.State
          count=0
          while 1: #until error is returned try to connect
              try:
 
                 self.send_command("atz")   # initialize
-                time.sleep(0.1)
+                time.sleep(0.2)
                 
              except serial.SerialException:
                 self.State = 0
@@ -110,18 +111,18 @@ class OBDPort:
              self.ELMver = self.get_result()
              print self.get_result()
              wx.PostEvent(self._notify_window, DebugEvent([2,"atz response:" + self.ELMver]))
-             print self.State
+             print "self.state: "+str(self.State)
 
              self.send_command("ate0")  # echo off
-             time.sleep(0.1)
+             time.sleep(0.2)
              print self.get_result()
              wx.PostEvent(self._notify_window, DebugEvent([2,"ate0 response:" + self.get_result()]))
 
              self.send_command("0100")
-             time.sleep(0.1)
+             time.sleep(0.2)
              ready = self.get_result()
              print ready
-             time.sleep(1.0)
+             time.sleep(1.2)
              wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response1:" + ready]))
 
 #UNABLE TO CONNECT
@@ -247,13 +248,19 @@ class OBDPort:
      # return string of sensor name and value from sensor index
      def sensor(self , sensor_index):
 
-         print "def sensor: "+ str(sensor_index)
+         log1="sensor: "+ str(sensor_index)
+         print log1
 
          """Returns 3-tuple of given sensors. 3-tuple consists of
          (Sensor Name (string), Sensor Value (string), Sensor Unit (string) ) """
          sensor = obd_sensors.SENSORS[sensor_index]
          r = self.get_sensor_value(sensor)
-         print "Sensor name: " + sensor.name
+
+         log1="Sensor: " + str(sensor.name)
+         print log1
+         log2="echo '"+log1+"' >> /home/user/MyDocs/pyobd.log"
+         os.popen(log2)
+
          #print "Sensor unit: " + sensor.unit
          return (sensor.name,r, sensor.unit)
 
