@@ -83,6 +83,14 @@ def fuel_trim_percent(code):
     code = hex_to_int(code)
     return (code - 128.0) * 100.0 / 128
 
+def o2_sensor(code):
+    numA = hex_to_int(code[:2]) #A byte
+    numB = hex_to_int(code[2:4]) #B byte
+    return str(numA/20.0)+"#"+str((numB-128)*100/128)
+
+
+
+
 #m agg
 def FuelRailPress(code):
     code = hex_to_int(code)
@@ -353,14 +361,14 @@ SENSORS = [
     Sensor("            Throttle Position", "0111", throttle_pos      ,"%"      ),
     Sensor("         Secondary Air Status", "0112", cpass             ,"BitEnc."),
     Sensor("       Location of O2 sensors", "0113", cpass             ,"BitEnc."),
-    Sensor("             O2 Sensor: 1 - 1", "0114", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 1 - 2", "0115", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 1 - 3", "0116", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 1 - 4", "0117", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 2 - 1", "0118", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 2 - 2", "0119", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 2 - 3", "011A", fuel_trim_percent ,"%"      ),
-    Sensor("             O2 Sensor: 2 - 4", "011B", fuel_trim_percent ,"%"      ),
+    Sensor("             O2 Sensor: 1 - 1", "0114", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 1 - 2", "0115", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 1 - 3", "0116", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 1 - 4", "0117", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 2 - 1", "0118", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 2 - 2", "0119", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 2 - 3", "011A", o2_sensor         ,"V#%"    ),
+    Sensor("             O2 Sensor: 2 - 4", "011B", o2_sensor         ,"V#%"    ),
     Sensor("              OBD Designation", "011C", cpass             ,"BitEnc."),
     Sensor("       Location of O2 sensors", "011D", cpass             ,"BitEnc."),
     Sensor("             Aux input status", "011E", cpass             ,"BitEnc."),
@@ -423,8 +431,8 @@ SENSORS = [
     Sensor("Short term 2 oxygen se. b2&b4", "0157", oxsens2           ,"%      "),
     Sensor("Long term 2 oxygen sen. b2&b4", "0158", oxsens2           ,"%      "),
     Sensor(" Fuel rail pressure(absolute)", "0159", FuelRailPressD    ,"kPa#psi"),
-    Sensor(" Relative acceler. pedal pos.", "015A", fuel_trim_percent ,"%      "),
-    Sensor("Hybrid battery remaining life", "015B", fuel_trim_percent ,"%      "),
+    Sensor(" Relative acceler. pedal pos.", "015A", throttle_pos      ,"%      "),
+    Sensor("Hybrid battery remaining life", "015B", throttle_pos      ,"%      "),
     Sensor("       Engine oil temperature", "015C", temp              ,"C#F    "),
     Sensor("        Fuel injection timing", "015D", pid15d            ,"degrees"),
     Sensor("             Engine fuel rate", "015E", pid15e            ,"L/h#gal/h"),
