@@ -37,6 +37,7 @@ import sys
 import serial
 import platform
 import time
+import datetime
 import ConfigParser #safe application configuration
 #import webbrowser #open browser from python
 
@@ -69,6 +70,7 @@ ID_HELP_ABOUT = 508
 ID_HELP_VISIT = 509
 ID_HELP_ORDER = 510
 ID_HELP_ABOUT_Maemo = 511
+ID_HELP_VISIT_Maemo = 512
 
 # Define notification event for sensor result window
 EVT_RESULT_ID = 1000
@@ -207,9 +209,19 @@ class MyApp(wx.App):
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connected"]))
             os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Connected to ECU"')
 
+            log2="echo Connected > /home/user/MyDocs/pyobd.log"
+            os.popen(log2)
+            log2="echo >> /home/user/MyDocs/pyobd.log"
+            os.popen(log2)
+
+
+
             wx.PostEvent(self._notify_window, StatusEvent([2,1,self.port.ELMver]))
             prevstate=-1
             curstate=-1
+
+
+
             while self._notify_window.ThreadControl!=666:
                 prevstate=curstate
                 curstate=self._nb.GetSelection()
@@ -221,6 +233,15 @@ class MyApp(wx.App):
                     wx.PostEvent(self._notify_window, TestEvent([i,1,res[i]]))
                 
                 elif curstate==2: #show sensor tab
+
+                  log2="echo  >> /home/user/MyDocs/pyobd.log"
+                  os.popen(log2)
+                  log1="time: "+str(datetime.datetime.now())
+                  log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
+                  os.popen(log2)
+                  log2="echo  >> /home/user/MyDocs/pyobd.log"
+                  os.popen(log2)
+
                   for i in range(3, len(self.active)):
 
 
@@ -230,6 +251,15 @@ class MyApp(wx.App):
                       if self.active[i]:
                           s = self.port.sensor(i)
                           wx.PostEvent(self._notify_window, ResultEvent([i,2,"%s (%s)" % (s[1], s[2])]))
+#log
+                          log1="Value : "+str(s[1])+" "+str(s[2])
+                          print log1
+                          log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
+                          os.popen(log2)
+                          log2="echo  >> /home/user/MyDocs/pyobd.log"
+                          os.popen(log2)
+
+
 
                       if self._notify_window.ThreadControl==666:
                           break
@@ -253,17 +283,36 @@ class MyApp(wx.App):
                     wx.PostEvent(self._notify_window, DTCEvent(0)) #clear list
                     DTCCodes=self.port.get_dtc()
 
-                    print DTCCodes
-                    #print DTCCodes[0][0] | bug with no DTC codes
-                    #print DTCCodes[0][1] | bug with no DTC codes
+
+                    #print DTCCodes
 
                     if len(DTCCodes)==0:
                       wx.PostEvent(self._notify_window, DTCEvent(["","","No DTC codes (codes cleared)"]))
+                      log1="Value :  No DTC codes or codes cleared"
+                      print log1
+                      log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
+                      os.popen(log2)
+                      log2="echo  >> /home/user/MyDocs/pyobd.log"
+                      os.popen(log2)
+
+
                     for i in range (0,len(DTCCodes)):
                       try:
                          wx.PostEvent(self._notify_window, DTCEvent([DTCCodes[i][1],DTCCodes[i][0],pcodes[DTCCodes[i][1]]]))
+                         log1="Value :  "+str(DTCCodes[i][1])+" "+str(DTCCodes[i][0])+" "+str(pcodes[DTCCodes[i][1]])
+                         print log1
+                         log2="echo '"+log1+"' >> /home/user/MyDocs/pyobd.log"
+                         os.popen(log2)
+                         log2="echo  >> /home/user/MyDocs/pyobd.log"
+                         os.popen(log2)
                       except:
                          wx.PostEvent(self._notify_window, DTCEvent([DTCCodes[i][1],DTCCodes[i][0],"? UNKNOWN"]))
+                         log1="Value :  "+str(DTCCodes[i][1])+" "+str(DTCCodes[i][0])+" ? UNKNOWN"
+                         print log1
+                         log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
+                         os.popen(log2)
+                         log2="echo  >> /home/user/MyDocs/pyobd.log"
+                         os.popen(log2)
                          pass
 
                 else:
@@ -509,10 +558,11 @@ class MyApp(wx.App):
 
         self.helpmenu = wx.Menu()
         
-        self.helpmenu.Append(ID_HELP_ABOUT  ,"About this program",   " Get DTC Codes")
+        self.helpmenu.Append(ID_HELP_ABOUT        ,"About this program",   " Get DTC Codes")
         self.helpmenu.Append(ID_HELP_ABOUT_Maemo  ,"About Maemo/n900",   " ")
-        self.helpmenu.Append(ID_HELP_VISIT  ,"Visit program homepage"," Lookup DTC Codes")
-        self.helpmenu.Append(ID_HELP_ORDER ,"Order OBD-II cables",  " Clear DTC Codes")
+        self.helpmenu.Append(ID_HELP_VISIT_Maemo  ,"Visit MAEMO Thread"," ")
+        self.helpmenu.Append(ID_HELP_VISIT        ,"Visit program homepage"," Lookup DTC Codes")
+        #self.helpmenu.Append(ID_HELP_ORDER        ,"Order OBD-II cables",  " Clear DTC Codes")
 
 
         # Creating the menubar.
@@ -534,6 +584,7 @@ class MyApp(wx.App):
         frame.Bind(wx.EVT_MENU,self.OnHelpAbout,id=ID_HELP_ABOUT) 
 
         frame.Bind(wx.EVT_MENU,self.OnHelpAboutMaemo,id=ID_HELP_ABOUT_Maemo) 
+        frame.Bind(wx.EVT_MENU,self.OnVisitMaemo,id=ID_HELP_VISIT_Maemo) 
 
         frame.Bind(wx.EVT_MENU,self.OnHelpVisit,id=ID_HELP_VISIT)
         frame.Bind(wx.EVT_MENU,self.OnHelpOrder,id=ID_HELP_ORDER)
@@ -548,6 +599,10 @@ class MyApp(wx.App):
 
         return True
 
+    def OnVisitMaemo(self,event):
+        stringa = 'dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"http://talk.maemo.org/showthread.php?t=81129"'
+        os.popen(stringa)
+
     def OnHelpVisit(self,event):
         #webbrowser.open("http://www.obdtester.com/pyobd")
         stringa = 'dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"http://www.obdtester.com/pyobd"'
@@ -561,17 +616,17 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """pyobd-0.9.2-11
+        Text = """pyobd-0.9.2-12beta
 Adapted to n900 by m750
 Now work only with BT ELM OBD devices. 
 
-Note: pyOBD does not recognize all the 
-error codes, especially those personalized 
-by cars factories. 
-Eventually you can edit the file: 
-  /home/opt/obd2_codes.py 
+pyOBD does not recognize all error 
+codes. You could edit the file: 
+   /home/opt/obd2_codes.py  
 to add this error codes. 
 
+Sensors are logged in: 
+  /home/user/MyDocs/pyobd.log  
 """
 
         self.HelpAboutMaemoDlg = wx.MessageDialog(self.frame, Text, 'About n900 adapting',wx.OK | wx.ICON_INFORMATION)
